==> clorn-0.1.0.tar.gz: clorn-0.1.0/clorn/apps.py <==
"""/
python library to make website pages
"""
import socket
import time
import re
import sys
#inner
from .ip_fetcher import get_ip
from clorn import forms
from .route import route
#----

def app(function):
	def response(host=socket.gethostbyname(socket.gethostname()), port=1599, debug=True):
		if host=='0.0.0.0':
			host=get_ip()
		else:
			host=host
		try:
			server=socket.socket(socket.AF_INET, socket.SOCK_STREAM)
			server.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
			server.bind((host, port))
			server.listen(1)
			print('website server started ')
			print('\033[31mWARNING: only for production development\033[0m')
			if debug == True:
				print('debug mode: on')
			elif debug == False:
				print('debug mode: off')
			else:
				print('unknown debug mode "'+str(debug)+'"')
			print('started time: '+str(time.ctime()))
			print('url: http://'+str(host)+':'+str(port)+'/')
			print('\r\n')
			print('logs:')
			while True:
				client, client_addres=server.accept()
				
				logs=client.recv(1024).decode()
				forms.request._request_=logs
				try:
					header=logs.split('\n')[0].split()[1]
				except IndexError:
					continue
				header=route(header)
				rtype=logs.split('\n')[0]
				try:
					if function(header) == None:
						url_for_cl='''<!DOCTYPE html>
<html lang="en">
<head>
				<meta charset="UTF-8">
				<title>500-internal server error</title>
</head>
<body>
				<h1 style="text-align: center;">500</h1>
				<p style="text-align: center;font-size:20px;">internal server error</p>
		
</html>'''
					else:
						url_for_cl=function(header)
				except Exception as error:
					ername=str(sys.exc_info())
					print(error)
					if debug==True:
						url_for_cl=f'''<!DOCTYPE html>
<html lang="en">
<head>
				<meta charset="UTF-8">
				<title>500-internal server error</title>
</head>
<body>
				<h1 style="text-align: center;">500</h1>
				<p style="text-align: center;font-size:20px;">internal server error</p>
				<p style="text-align: center;font-size:20px;">please check your code and try again.</p>
errors[<br/>
error: {ername}<br/>
error message: {error}<br/>
]
</body>
</html>'''
					elif debug == False:
						print(ername)
						url_for_cl='''<!DOCTYPE html>
<html lang="en">
<head>
				<meta charset="UTF-8">
				<title>500-internal server error</title>
</head>
<body>
				<h1 style="text-align: center;">500</h1>
				<p style="text-align: center;font-size:20px;">internal server error</p>
				
</body>
</html>'''
					else:
						url_for_cl='''<!DOCTYPE html>
<html lang="en">
<head>
				<meta charset="UTF-8">
				<title>500-internal server error</title>
</head>
<body>
				<h1 style="text-align: center;">500</h1>
				<p style="text-align: center;font-size:20px;">internal server error</p>
				<p style="text-align: center;font-size:20px;">please check your code and try again.</p>
<h3>unknown debug mode</h3>
</body>
</html>'''
				if str(url_for_cl).startswith('$404$'):
					print('serving 404 page')
					response="HTTP/1.1 404 NOT FOUND\r\nContent-Type: text/html\r\n\r\n<!DOCTYPE html>"+str(url_for_cl)[5:]
				else:
					response="HTTP/1.1 200 OK\r\nContent-Type: text/html\r\n\r\n<!DOCTYPE html>"+str(url_for_cl)
				try:
					cadr=str(client_addres[0])
				except IndexError:
					cadr=''
				print('['+str(time.ctime())+'] '+str(rtype).replace(' ', '  '))
				client.sendall(response.encode())
				client.close()
			server.close()
		except KeyboardInterrupt:
			print('server stopped')
			#stpwtc
			print('stopped at '+str(time.ctime()))
			#stpwtc
		except socket.gaierror as ser:
			if 'No address associated with hostname' in str(ser):
				print('address could not be found')
			else:
				print('unknown error on network')
				print('logs:')
				print(ser)
	return response

==> clorn-0.1.6.tar.gz: clorn-0.1.6/clorn/apps.py <==
"""/
python library to make website pages
"""
import socket
import time
import re
import os
import sys
#inner
from .ip_fetcher import get_ip
from clorn import forms
from .route import route
#----
class APP_NAME:
	name=None
try:
	dport = int(os.environ['SERVER_PORT'])
except:
	dport=1599
try:
	dhost = os.environ['SERVER_NAME']
except:
	dhost = socket.gethostbyname(socket.gethostname())
def app(function):
	def response(host=dhost, port=dport, debug=True):
		if host=='0.0.0.0':
			host=get_ip()
		else:
			host=host
		try:
			server=socket.socket(socket.AF_INET, socket.SOCK_STREAM)
			server.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
			server.bind((host, port))
			server.listen(1)
			print('website server started ')
			print('\033[31mWARNING: only for production development\033[0m')
			if debug == True:
				print('debug mode: on')
			elif debug == False:
				print('debug mode: off')
			else:
				print('unknown debug mode "'+str(debug)+'"')
			print('started time: '+str(time.ctime()))
			print('url: http://'+str(host)+':'+str(port)+'/')
			print('\r\n')
			print('logs:')
			while True:
				client, client_addres=server.accept()
				
				logs=client.recv(1024).decode()
				forms.request._request_=logs
				try:
					header=logs.split('\n')[0].split()[1]
				except IndexError:
					continue
				header=route(header)
				rtype=logs.split('\n')[0]
				try:
					if function(header) == None:
						url_for_cl='''<!DOCTYPE html>
<html lang="en">
<head>
				<meta charset="UTF-8">
				<title>500-internal server error</title>
</head>
<body>
				<h1 style="text-align: center;">500</h1>
				<p style="text-align: center;font-size:20px;">internal server error</p>
		
</html>'''
					else:
						url_for_cl=function(header)
				except Exception as error:
					ername=str(sys.exc_info())
					print(error)
					if debug==True:
						url_for_cl=f'''<!DOCTYPE html>
<html lang="en">
<head>
				<meta charset="UTF-8">
				<title>500-internal server error</title>
</head>
<body>
				<h1 style="text-align: center;">500</h1>
				<p style="text-align: center;font-size:20px;">internal server error</p>
				<p style="text-align: center;font-size:20px;">please check your code and try again.</p>
errors[<br/>
error: {ername}<br/>
error message: {error}<br/>
]
</body>
</html>'''
					elif debug == False:
						print(ername)
						url_for_cl='''<!DOCTYPE html>
<html lang="en">
<head>
				<meta charset="UTF-8">
				<title>500-internal server error</title>
</head>
<body>
				<h1 style="text-align: center;">500</h1>
				<p style="text-align: center;font-size:20px;">internal server error</p>
				
</body>
</html>'''
					else:
						url_for_cl='''<!DOCTYPE html>
<html lang="en">
<head>
				<meta charset="UTF-8">
				<title>500-internal server error</title>
</head>
<body>
				<h1 style="text-align: center;">500</h1>
				<p style="text-align: center;font-size:20px;">internal server error</p>
				<p style="text-align: center;font-size:20px;">please check your code and try again.</p>
<h3>unknown debug mode</h3>
</body>
</html>'''
				if str(url_for_cl).startswith('$404$'):
					print('serving 404 page')
					response="HTTP/1.1 404 NOT FOUND\r\nContent-Type: text/html\r\n\r\n<!DOCTYPE html>"+str(url_for_cl)[5:]
				else:
					response="HTTP/1.1 200 OK\r\nContent-Type: text/html\r\n\r\n<!DOCTYPE html>"+str(url_for_cl)
				try:
					cadr=str(client_addres[0])
				except IndexError:
					cadr=''
				print('['+str(time.ctime())+'] '+str(rtype).replace(' ', '  '))
				client.sendall(response.encode())
				client.close()
			server.close()
		except KeyboardInterrupt:
			print('server stopped')
			#stpwtc
			print('stopped at '+str(time.ctime()))
			#stpwtc
		except socket.gaierror as ser:
			if 'No address associated with hostname' in str(ser):
				print('address could not be found')
			else:
				print('unknown error on network')
				print('logs:')
				print(ser)
		APP_NAME.name=response
	return response
